@@ -11,5 +11,8 @@ class Spinne():
 
     def render(self, function):
         @self.app.route("/<route>")
+        @self.app.route("/")
         def locate(route):
+            if not route:
+                return function("index")
             return function(route)
