@@ -1,12 +1,13 @@
-main = """from spinne import Spinne, pageNotFound
+main = """from spinne import Spinne, page_not_found
+
+# import views:
 import index
 
 app = Spinne("site")
 
 @app.render
 def main(route):
-    print(route)
-    if route == "test":
+    if route == "index" or "": # you can use any route you'd like
         return index.index()
     else:
         return pageNotFound()
